@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=C0301,W0105,W0401,W0614
 
-import sys
-import yaml
-import msgpack
 import collections
 
+import json
+import msgpack
+
 from tarantool.const import (
     IPROTO_CODE,
     IPROTO_DATA,
@@ -22,10 +22,6 @@ from tarantool.error import (
 )
 
 
-if sys.version_info < (2, 6):
-    bytes = str    # pylint: disable=W0622
-
-
 class Response(collections.Sequence):
     '''
     Represents a single response from the server in compliance with the
@@ -46,8 +42,8 @@ class Response(collections.Sequence):
         '''
 
         # This is not necessary, because underlying list data structures are
-        # created in the __new__(). But let it be.
-        super(Response, self).__init__()
+        # created in the __new__().
+        # super(Response, self).__init__()
 
         if conn.encoding is not None:
             unpacker = msgpack.Unpacker(use_list=True, encoding=conn.encoding)
@@ -225,12 +221,17 @@ class Response(collections.Sequence):
         :rtype: str or None
         '''
         if self.return_code:
-            return yaml.dump({
+            return json.dumps({
                 'error': {
                     'code': self.strerror[0],
                     'reason': self.return_message
                 }
-            })
-        return yaml.dump(self._data)
+            }, sort_keys = True, indent = 4)
+        output = []
+        for tpl in self._data:
+            output.extend(("- ", repr(tpl), "\n"))
+        if len(output) > 0:
+            output.pop()
+        return ''.join(output)
 
     __repr__ = __str__
